@@ -11,6 +11,8 @@ from building_plus.read.weather_file import read_weather_file
 from building_plus.read.load_data import load_data
 from building_plus.read.load_building import load_building
 from building_plus.read.example_file import load_example_file
+from building_plus.process.forecast_dr_capacity import forecast_dr_capacity
+
 
 def validate_building(build = 1,climate = '4A', start_day = 1, duration = 10, horizon = 0, mode = 'build',warmup = 'new'):
     ''''sim' for model predictive control simulation, 'build' for simulating a building without external control, 'warmup' just to warm up and save a model
@@ -55,4 +57,30 @@ def validate_building(build = 1,climate = '4A', start_day = 1, duration = 10, ho
             plot_sim(facility,T_zone,Q_transfer,building,date[1:],USER_DIR_EPLUS / ('RefBldg'+build + 'New2004_v1.4_7.2_' + climate+'.csv'))
     elif mode == 'sim':
         test_data = load_data(building, weather, date, T_zone[-1], humidity[-1])##load test_data: actual internal gains and weather different from forecast schedules?
-        facility, net_elec = run_sim(building, test_data, weather, [T_zone[-1]], [T_surf[-1]], [humidity[-1]], date, horizon)
\ No newline at end of file
+        facility, net_elec = run_sim(building, test_data, weather, [T_zone[-1]], [T_surf[-1]], [humidity[-1]], date, horizon)
+
+
+def test_forecast_dr(build = 1,climate = '4A', start_day = 1, horizon = 0):
+    '''
+
+    '''
+    if isinstance(build,int):
+        build = BUILD_NAMES[build-1]
+    climate = CLIMATE_NAMES[climate]
+    try:
+        weather = read_weather_file(load_example_file(climate + '_TMY2.epw', 'eplus_weather'),'tmy')
+        building = load_building(load_example_file('RefBldg'+build + 'New2004_v1.4_7.2_' + climate, 'eplus_buildings', suffixes=['.idf', '.eio']))
+    except FileNotFoundError:
+        weather = read_weather_file(USER_DIR_ENERGYPLUS_WEATHER / (climate + '_TMY2.epw'),'tmy')
+        building = load_building(USER_DIR_BUILDINGS / ('RefBldg'+build + 'New2004_v1.4_7.2_' + climate))
+    T_zone,T_surf,humidity,frost = building_warmup(building, weather, building['sim_date'][24*(start_day-1)], False)
+    observer = {}
+    observer['building_zone_temp'] = [T_zone[-1]]
+    observer['building_surf_temp'] = [T_surf[-1]]
+    observer['building_humidity'] = [humidity[-1]]
+    observer['building_supply'] =  [building['plant_loop']['exit_temperature']] #supply 'tank' temperature
+    date = [building['sim_date'][i+24*(start_day-1)] for i in range(horizon+1)]
+    forecast = forecast_dr_capacity([building],observer,weather,date)
+    return forecast
+
+    
\ No newline at end of file
